<?php

/**
 * @file
 * Admin page callbacks for the system configuration settings.
 */

/**
 * Module admin configuraion form.
 */
function drupaltosugar_system_configuration() {
  $form['fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('System Configuration'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['fieldset']['sugarcrm_url'] = array(
    '#type' => 'textfield', 
    '#title' => t('SugarCRM URL'),
    '#description' => t('Enter the URL of SugarCRM System like http://example.com'),
    '#default_value' => isset($_SESSION['crmurl']) ? $_SESSION['crmurl'] : variable_get('sugarcrm_url', NULL),
  );
  $form['fieldset']['sugarcrm_username'] = array(
    '#type' => 'textfield',
    '#title' => t('User Name'),
    '#description' => t('Enter your SugarCRM User Name'),
    '#default_value' => isset($_SESSION['crmusername']) ? $_SESSION['crmusername'] : variable_get('sugarcrm_username', NULL),
  );
  $pass = variable_get('sugarcrm_pass', NULL);
  if ($pass) {
    $description = t('To change current password, please enter new password.');
  }
  else {
    $description = t('Enter Password for SugarCRM.');
  }
  $form['fieldset']['sugarcrm_pass'] = array(
    '#type' => 'password',
    '#title' => t('Password'),
    '#description' => $description,
  );
  $msg_div = '<div id="test-connection-result"></div>';
  $msg_div .= '<div id="test-connection-id" class="custom-submit">' . t('Test Connection') . '</div>';
  $form['fieldset']['test_connection'] = array(
    '#markup' => $msg_div,
  );
  $form['save'] = array(
    '#type' => 'submit',
    '#value' => t('Save System Settings'),
  );
  return $form;
}

/**
 * Implements hook_submit().
 */
function drupaltosugar_system_configuration_submit(&$form, &$form_state) {
  $crm_url = trim($form_state['values']['sugarcrm_url']);
  $crm_user_name = trim($form_state['values']['sugarcrm_username']);
  $pass = trim($form_state['values']['sugarcrm_pass']);
  if ($pass) {
    $crm_pass = $pass;
  }
  elseif (isset($_SESSION['crmpass'])) {
  $crm_pass = $_SESSION['crmpass'];
  }
  else {
    $crm_pass = variable_get('sugarcrm_pass', NULL);
  }
  unset($_SESSION['crmurl'], $_SESSION['crmusername'], $_SESSION['crmpass']);
  variable_set('sugarcrm_url', $crm_url);
  variable_set('sugarcrm_username', $crm_user_name);
  variable_set('sugarcrm_pass', $crm_pass);
  drupal_set_message(t('System Configuration has been saved Successfully'));
}

/**
 * Function for testing SugarCRM connection.
 */
function drupaltosugar_test_connection() {
  $url = trim($_POST['sugarcrm_url']);
  $user = trim($_POST['sugarcrm_user']);
  $pass = trim($_POST['sugarcrm_pass']);
  if ($pass) {
    $crm_pass = $pass;
  }
  else {
    $crm_pass = variable_get('sugarcrm_pass', NULL);
  }
  $_SESSION['crmpass'] = $crm_pass;
  $client = new nusoap_client($url . '/customsoap.php?wsdl');
  $user_auth = array(
    'user_auth' => array(
      'user_name' => $user,
      'password' =>  md5($crm_pass)
    )
  );
  $result_array = $client->call('login', $user_auth);
  if (is_array($result_array) && array_key_exists('id', $result_array)) {
    $msg = '<div id="connection-result" class="messages-status">' . t('Successfully connected') . '</div>';
  }
  else {
    $msg = '<div id="connection-result" class="messages-error">' . t('Unable to connect, Please check login credentials') . '</div>';
  }
  print $msg;
}

/**
 * Cron configuration form.
 */
function drupaltosugar_cron_configuration_form() {
  $interval = array(
    '1' => 'Instant Sent',
    '60' => '1 Minute',
    '120' => '2 Minute',
    '360' => '5 Minute',
    '900' => '15 Minute',
    '1800' => '30 Minute',
    '3600' => '1 Hour',
    '86400' => '1 Day',
    '604800' => '1 Week',
  );
  $error_attempts = array(
    '1' => '1',
    '2' => '2',
    '3' => '3',
    '4' => '4',
    '5' => '5',
    '6' => '6',
    '7' => '7',
    '8' => '8',
    '9' => '9',
    '10' => '10',
  );

  if (arg(3) && arg(3) == 'content_type') {
    $drupal_form_type = 'content-type';
    $fieldset_title = t('Cron Interval- Content Type');
  }
  else {
    $drupal_form_type = 'webform';
    $fieldset_title = t('Cron Interval- Webform');
  }
  $form['form_type'] = array(
    '#type' => 'hidden',
    '#value' => check_plain($drupal_form_type),
  );
  $form['cron_interval'] = array(
    '#type' => 'fieldset',
    '#title' => check_plain($fieldset_title),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#prefix' => '<div class = "webform-cron-interval">',
    '#suffix' => '</div>',
  );

  $webform_data = drupaltosugar_drupal_form_mapped($drupal_form_type);
  if ($webform_data) {
    foreach ($webform_data as $key => $value) {
      $variable_name = $drupal_form_type . 'cron_' . $key;
      $error_attempt = $drupal_form_type . 'error_' . $key;
      $form['cron_interval']['interval'][$variable_name] = array(
        '#title' => t('Time Interval'),
        '#type' => 'select',
        '#options' => $interval,
        '#default_value' => variable_get($variable_name, '60'),
        '#required' => TRUE,
        '#prefix' => '<div class = "webform-interval">' . '<lable>' . check_plain(ucwords($value)) . '</lable>',
      );
      $form['cron_interval']['interval'][$error_attempt] = array(
        '#type' => 'select',
        '#title' => t('No. of error attempts'),
        '#options' => $error_attempts,
        '#default_value' => variable_get($error_attempt, '1'),
        '#required' => TRUE,
        '#suffix' => '</div>'
      );
    }
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
    );
  }
  else {
    $form_type = ucwords(str_replace('-', ' ', $drupal_form_type));
    $form['cron_interval']['msg'] =array (
      '#markup' => t('There is no !form_type mapped yet.', array('!form_type' => $form_type)),
    );
  }
  return $form;
}

/**
 * Function to save cron configuration for each mapped webform.
 */
function drupaltosugar_cron_configuration_form_submit($form, &$form_state) {
  $form_type = $form_state['values']['form_type'];
  foreach ($form_state['values'] as $key => $value) {
    $nid = explode('_', $key);
    if ($nid[0] == 'webformcron' || $nid[0] == 'content-typecron') {
      $form_name = $nid[0] . '_' . $nid[1];
      $form_next_exe = $form_type . '_next_exe' . $nid[1];
      variable_set($form_name, $value);
      variable_set($form_next_exe, 0);
    }
    elseif ($nid[0] == 'webformerror' || $nid[0] == 'content-typeerror') {
      $form_error_attempt = $form_type . 'error_' . $nid[1];
      variable_set($form_error_attempt, $value);
    }
  }
  drupal_set_message(t("Cron configuration has been saved"));
}